/*
Copyright (c) 2013-2018, Tom Schoonjans
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:
    * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
    * The names of the contributors may not be used to endorse or promote products derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY Tom Schoonjans ''AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL Tom Schoonjans BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

/*
 * This file was automatically generated by nist-compounds.pl
 * Modify at your own risk...
 */

#include <xraylib-nist-compounds.h>

static const int nCompoundDataNISTList = 180;
static int __CompoundDataNISTList_Elements_0[] = {1, 6, 7, 8, 9, 20};
static double __CompoundDataNISTList_massFractions_0[] = {0.101327, 0.775501, 0.035057, 0.052316, 0.017422, 0.018378};
static int __CompoundDataNISTList_Elements_1[] = {1, 6, 8};
static double __CompoundDataNISTList_massFractions_1[] = {0.104122, 0.620405, 0.275473};
static int __CompoundDataNISTList_Elements_2[] = {1, 6};
static double __CompoundDataNISTList_massFractions_2[] = {0.077418, 0.922582};
static int __CompoundDataNISTList_Elements_3[] = {1, 6, 7};
static double __CompoundDataNISTList_massFractions_3[] = {0.037294, 0.444430, 0.518275};
static int __CompoundDataNISTList_Elements_4[] = {1, 6, 7, 8, 11, 12, 15, 16, 17, 19, 20, 26, 30};
static double __CompoundDataNISTList_massFractions_4[] = {0.119477, 0.637240, 0.007970, 0.232333, 0.000500, 0.000020, 0.000160, 0.000730, 0.001190, 0.000320, 0.000020, 0.000020, 0.000020};
static int __CompoundDataNISTList_Elements_5[] = {6, 7, 8, 18};
static double __CompoundDataNISTList_massFractions_5[] = {0.000124, 0.755267, 0.231781, 0.012827};
static int __CompoundDataNISTList_Elements_6[] = {1, 6, 7, 8};
static double __CompoundDataNISTList_massFractions_6[] = {0.079190, 0.404439, 0.157213, 0.359159};
static int __CompoundDataNISTList_Elements_7[] = {8, 13};
static double __CompoundDataNISTList_massFractions_7[] = {0.470749, 0.529251};
static int __CompoundDataNISTList_Elements_8[] = {1, 6, 8};
static double __CompoundDataNISTList_massFractions_8[] = {0.105930, 0.788973, 0.105096};
static int __CompoundDataNISTList_Elements_9[] = {1, 7};
static double __CompoundDataNISTList_massFractions_9[] = {0.177547, 0.822453};
static int __CompoundDataNISTList_Elements_10[] = {1, 6, 7};
static double __CompoundDataNISTList_massFractions_10[] = {0.075759, 0.773838, 0.150403};
static int __CompoundDataNISTList_Elements_11[] = {1, 6};
static double __CompoundDataNISTList_massFractions_11[] = {0.056550, 0.943450};
static int __CompoundDataNISTList_Elements_12[] = {1, 6, 7, 8, 9, 20};
static double __CompoundDataNISTList_massFractions_12[] = {0.065471, 0.536945, 0.021500, 0.032085, 0.167411, 0.176589};
static int __CompoundDataNISTList_Elements_13[] = {1, 6, 8};
static double __CompoundDataNISTList_massFractions_13[] = {0.057441, 0.774591, 0.167968};
static int __CompoundDataNISTList_Elements_14[] = {9, 56};
static double __CompoundDataNISTList_massFractions_14[] = {0.216720, 0.783280};
static int __CompoundDataNISTList_Elements_15[] = {8, 16, 56};
static double __CompoundDataNISTList_massFractions_15[] = {0.274212, 0.137368, 0.588420};
static int __CompoundDataNISTList_Elements_16[] = {1, 6};
static double __CompoundDataNISTList_massFractions_16[] = {0.077418, 0.922582};
static int __CompoundDataNISTList_Elements_17[] = {4, 8};
static double __CompoundDataNISTList_massFractions_17[] = {0.360320, 0.639680};
static int __CompoundDataNISTList_Elements_18[] = {8, 32, 83};
static double __CompoundDataNISTList_massFractions_18[] = {0.154126, 0.174820, 0.671054};
static int __CompoundDataNISTList_Elements_19[] = {1, 6, 7, 8, 11, 12, 14, 15, 16, 17, 19, 20, 26, 30};
static double __CompoundDataNISTList_massFractions_19[] = {0.101866, 0.100020, 0.029640, 0.759414, 0.001850, 0.000040, 0.000030, 0.000350, 0.001850, 0.002780, 0.001630, 0.000060, 0.000460, 0.000010};
static int __CompoundDataNISTList_Elements_20[] = {1, 6, 7, 8, 12, 15, 16, 20};
static double __CompoundDataNISTList_massFractions_20[] = {0.063984, 0.278000, 0.027000, 0.410016, 0.002000, 0.070000, 0.002000, 0.147000};
static int __CompoundDataNISTList_Elements_21[] = {1, 6, 7, 8, 12, 15, 16, 20, 30};
static double __CompoundDataNISTList_massFractions_21[] = {0.047234, 0.144330, 0.041990, 0.446096, 0.002200, 0.104970, 0.003150, 0.209930, 0.000100};
static int __CompoundDataNISTList_Elements_22[] = {5, 6};
static double __CompoundDataNISTList_massFractions_22[] = {0.782610, 0.217390};
static int __CompoundDataNISTList_Elements_23[] = {5, 8};
static double __CompoundDataNISTList_massFractions_23[] = {0.310551, 0.689449};
static int __CompoundDataNISTList_Elements_24[] = {1, 6, 7, 8, 11, 12, 15, 16, 17, 19, 20, 26, 30};
static double __CompoundDataNISTList_massFractions_24[] = {0.110667, 0.125420, 0.013280, 0.737723, 0.001840, 0.000150, 0.003540, 0.001770, 0.002360, 0.003100, 0.000090, 0.000050, 0.000010};
static int __CompoundDataNISTList_Elements_25[] = {1, 6};
static double __CompoundDataNISTList_massFractions_25[] = {0.173408, 0.826592};
static int __CompoundDataNISTList_Elements_26[] = {1, 6, 8};
static double __CompoundDataNISTList_massFractions_26[] = {0.135978, 0.648171, 0.215851};
static int __CompoundDataNISTList_Elements_27[] = {1, 6, 8, 9, 14};
static double __CompoundDataNISTList_massFractions_27[] = {0.024680, 0.501610, 0.004527, 0.465209, 0.003973};
static int __CompoundDataNISTList_Elements_28[] = {48, 52};
static double __CompoundDataNISTList_massFractions_28[] = {0.468355, 0.531645};
static int __CompoundDataNISTList_Elements_29[] = {8, 48, 74};
static double __CompoundDataNISTList_massFractions_29[] = {0.177644, 0.312027, 0.510329};
static int __CompoundDataNISTList_Elements_30[] = {6, 8, 20};
static double __CompoundDataNISTList_massFractions_30[] = {0.120003, 0.479554, 0.400443};
static int __CompoundDataNISTList_Elements_31[] = {9, 20};
static double __CompoundDataNISTList_massFractions_31[] = {0.486659, 0.513341};
static int __CompoundDataNISTList_Elements_32[] = {8, 20};
static double __CompoundDataNISTList_massFractions_32[] = {0.285299, 0.714701};
static int __CompoundDataNISTList_Elements_33[] = {8, 16, 20};
static double __CompoundDataNISTList_massFractions_33[] = {0.470095, 0.235497, 0.294408};
static int __CompoundDataNISTList_Elements_34[] = {8, 20, 74};
static double __CompoundDataNISTList_massFractions_34[] = {0.222270, 0.139202, 0.638529};
static int __CompoundDataNISTList_Elements_35[] = {6, 8};
static double __CompoundDataNISTList_massFractions_35[] = {0.272916, 0.727084};
static int __CompoundDataNISTList_Elements_36[] = {6, 17};
static double __CompoundDataNISTList_massFractions_36[] = {0.078083, 0.921917};
static int __CompoundDataNISTList_Elements_37[] = {1, 6, 8};
static double __CompoundDataNISTList_massFractions_37[] = {0.062162, 0.444462, 0.493376};
static int __CompoundDataNISTList_Elements_38[] = {1, 6, 8};
static double __CompoundDataNISTList_massFractions_38[] = {0.067125, 0.545403, 0.387472};
static int __CompoundDataNISTList_Elements_39[] = {1, 6, 7, 8};
static double __CompoundDataNISTList_massFractions_39[] = {0.029216, 0.271296, 0.121276, 0.578212};
static int __CompoundDataNISTList_Elements_40[] = {1, 7, 8, 16, 58};
static double __CompoundDataNISTList_massFractions_40[] = {0.107596, 0.000800, 0.874976, 0.014627, 0.002001};
static int __CompoundDataNISTList_Elements_41[] = {9, 55};
static double __CompoundDataNISTList_massFractions_41[] = {0.125069, 0.874931};
static int __CompoundDataNISTList_Elements_42[] = {53, 55};
static double __CompoundDataNISTList_massFractions_42[] = {0.488451, 0.511549};
static int __CompoundDataNISTList_Elements_43[] = {1, 6, 17};
static double __CompoundDataNISTList_massFractions_43[] = {0.044772, 0.640254, 0.314974};
static int __CompoundDataNISTList_Elements_44[] = {1, 6, 17};
static double __CompoundDataNISTList_massFractions_44[] = {0.008443, 0.100613, 0.890944};
static int __CompoundDataNISTList_Elements_45[] = {1, 6, 8, 11, 12, 13, 14, 19, 20, 26};
static double __CompoundDataNISTList_massFractions_45[] = {0.010000, 0.001000, 0.529107, 0.016000, 0.002000, 0.033872, 0.337021, 0.013000, 0.044000, 0.014000};
static int __CompoundDataNISTList_Elements_46[] = {1, 6};
static double __CompoundDataNISTList_massFractions_46[] = {0.143711, 0.856289};
static int __CompoundDataNISTList_Elements_47[] = {1, 6, 17};
static double __CompoundDataNISTList_massFractions_47[] = {0.027425, 0.490233, 0.482342};
static int __CompoundDataNISTList_Elements_48[] = {1, 6, 8, 17};
static double __CompoundDataNISTList_massFractions_48[] = {0.056381, 0.335942, 0.111874, 0.495802};
static int __CompoundDataNISTList_Elements_49[] = {1, 6, 17};
static double __CompoundDataNISTList_massFractions_49[] = {0.040740, 0.242746, 0.716515};
static int __CompoundDataNISTList_Elements_50[] = {1, 6, 8};
static double __CompoundDataNISTList_massFractions_50[] = {0.135978, 0.648171, 0.215851};
static int __CompoundDataNISTList_Elements_51[] = {1, 6, 7, 8};
static double __CompoundDataNISTList_massFractions_51[] = {0.096523, 0.492965, 0.191625, 0.218887};
static int __CompoundDataNISTList_Elements_52[] = {1, 6, 8, 16};
static double __CompoundDataNISTList_massFractions_52[] = {0.077403, 0.307467, 0.204782, 0.410348};
static int __CompoundDataNISTList_Elements_53[] = {1, 6};
static double __CompoundDataNISTList_massFractions_53[] = {0.201115, 0.798885};
static int __CompoundDataNISTList_Elements_54[] = {1, 6, 8};
static double __CompoundDataNISTList_massFractions_54[] = {0.131269, 0.521438, 0.347294};
static int __CompoundDataNISTList_Elements_55[] = {1, 6, 8};
static double __CompoundDataNISTList_massFractions_55[] = {0.090027, 0.585182, 0.324791};
static int __CompoundDataNISTList_Elements_56[] = {1, 6};
static double __CompoundDataNISTList_massFractions_56[] = {0.143711, 0.856289};
static int __CompoundDataNISTList_Elements_57[] = {1, 6, 7, 8};
static double __CompoundDataNISTList_massFractions_57[] = {0.099269, 0.193710, 0.053270, 0.653751};
static int __CompoundDataNISTList_Elements_58[] = {8, 26};
static double __CompoundDataNISTList_massFractions_58[] = {0.300567, 0.699433};
static int __CompoundDataNISTList_Elements_59[] = {5, 26};
static double __CompoundDataNISTList_massFractions_59[] = {0.162174, 0.837826};
static int __CompoundDataNISTList_Elements_60[] = {8, 26};
static double __CompoundDataNISTList_massFractions_60[] = {0.222689, 0.777311};
static int __CompoundDataNISTList_Elements_61[] = {1, 7, 8, 11, 16, 17, 26};
static double __CompoundDataNISTList_massFractions_61[] = {0.108259, 0.000027, 0.878636, 0.000022, 0.012968, 0.000034, 0.000054};
static int __CompoundDataNISTList_Elements_62[] = {6, 9, 17};
static double __CompoundDataNISTList_massFractions_62[] = {0.099335, 0.314247, 0.586418};
static int __CompoundDataNISTList_Elements_63[] = {6, 9, 35};
static double __CompoundDataNISTList_massFractions_63[] = {0.057245, 0.181096, 0.761659};
static int __CompoundDataNISTList_Elements_64[] = {6, 9, 17};
static double __CompoundDataNISTList_massFractions_64[] = {0.114983, 0.545622, 0.339396};
static int __CompoundDataNISTList_Elements_65[] = {6, 9, 35};
static double __CompoundDataNISTList_massFractions_65[] = {0.080659, 0.382749, 0.536592};
static int __CompoundDataNISTList_Elements_66[] = {6, 9, 53};
static double __CompoundDataNISTList_massFractions_66[] = {0.061309, 0.290924, 0.647767};
static int __CompoundDataNISTList_Elements_67[] = {8, 16, 64};
static double __CompoundDataNISTList_massFractions_67[] = {0.084528, 0.084690, 0.830782};
static int __CompoundDataNISTList_Elements_68[] = {31, 33};
static double __CompoundDataNISTList_massFractions_68[] = {0.482019, 0.517981};
static int __CompoundDataNISTList_Elements_69[] = {1, 6, 7, 8, 16};
static double __CompoundDataNISTList_massFractions_69[] = {0.081180, 0.416060, 0.111240, 0.380640, 0.010880};
static int __CompoundDataNISTList_Elements_70[] = {5, 8, 11, 13, 14, 19};
static double __CompoundDataNISTList_massFractions_70[] = {0.040064, 0.539562, 0.028191, 0.011644, 0.377220, 0.003321};
static int __CompoundDataNISTList_Elements_71[] = {8, 14, 22, 33, 82};
static double __CompoundDataNISTList_massFractions_71[] = {0.156453, 0.080866, 0.008092, 0.002651, 0.751938};
static int __CompoundDataNISTList_Elements_72[] = {8, 11, 14, 20};
static double __CompoundDataNISTList_massFractions_72[] = {0.459800, 0.096441, 0.336553, 0.107205};
static int __CompoundDataNISTList_Elements_73[] = {1, 6, 8};
static double __CompoundDataNISTList_massFractions_73[] = {0.071204, 0.363652, 0.565144};
static int __CompoundDataNISTList_Elements_74[] = {1, 6, 7, 8};
static double __CompoundDataNISTList_massFractions_74[] = {0.068965, 0.410926, 0.191681, 0.328427};
static int __CompoundDataNISTList_Elements_75[] = {1, 6, 8};
static double __CompoundDataNISTList_massFractions_75[] = {0.087554, 0.391262, 0.521185};
static int __CompoundDataNISTList_Elements_76[] = {1, 6, 7, 8};
static double __CompoundDataNISTList_massFractions_76[] = {0.033346, 0.397380, 0.463407, 0.105867};
static int __CompoundDataNISTList_Elements_77[] = {1, 8, 16, 20};
static double __CompoundDataNISTList_massFractions_77[] = {0.023416, 0.557572, 0.186215, 0.232797};
static int __CompoundDataNISTList_Elements_78[] = {1, 6};
static double __CompoundDataNISTList_massFractions_78[] = {0.160937, 0.839063};
static int __CompoundDataNISTList_Elements_79[] = {1, 6};
static double __CompoundDataNISTList_massFractions_79[] = {0.163741, 0.836259};
static int __CompoundDataNISTList_Elements_80[] = {1, 6, 7, 8};
static double __CompoundDataNISTList_massFractions_80[] = {0.026362, 0.691133, 0.073270, 0.209235};
static int __CompoundDataNISTList_Elements_81[] = {8, 35, 57};
static double __CompoundDataNISTList_massFractions_81[] = {0.068138, 0.340294, 0.591568};
static int __CompoundDataNISTList_Elements_82[] = {8, 16, 57};
static double __CompoundDataNISTList_massFractions_82[] = {0.093600, 0.093778, 0.812622};
static int __CompoundDataNISTList_Elements_83[] = {8, 82};
static double __CompoundDataNISTList_massFractions_83[] = {0.071682, 0.928318};
static int __CompoundDataNISTList_Elements_84[] = {1, 3, 7};
static double __CompoundDataNISTList_massFractions_84[] = {0.087783, 0.302262, 0.609955};
static int __CompoundDataNISTList_Elements_85[] = {3, 6, 8};
static double __CompoundDataNISTList_massFractions_85[] = {0.187871, 0.162550, 0.649579};
static int __CompoundDataNISTList_Elements_86[] = {3, 9};
static double __CompoundDataNISTList_massFractions_86[] = {0.267585, 0.732415};
static int __CompoundDataNISTList_Elements_87[] = {1, 3};
static double __CompoundDataNISTList_massFractions_87[] = {0.126797, 0.873203};
static int __CompoundDataNISTList_Elements_88[] = {3, 53};
static double __CompoundDataNISTList_massFractions_88[] = {0.051858, 0.948142};
static int __CompoundDataNISTList_Elements_89[] = {3, 8};
static double __CompoundDataNISTList_massFractions_89[] = {0.464570, 0.535430};
static int __CompoundDataNISTList_Elements_90[] = {3, 5, 8};
static double __CompoundDataNISTList_massFractions_90[] = {0.082085, 0.255680, 0.662235};
static int __CompoundDataNISTList_Elements_91[] = {1, 6, 7, 8, 11, 12, 15, 16, 17, 19, 20, 26, 30};
static double __CompoundDataNISTList_massFractions_91[] = {0.101278, 0.102310, 0.028650, 0.757072, 0.001840, 0.000730, 0.000800, 0.002250, 0.002660, 0.001940, 0.000090, 0.000370, 0.000010};
static int __CompoundDataNISTList_Elements_92[] = {1, 6, 8, 12, 20};
static double __CompoundDataNISTList_massFractions_92[] = {0.114318, 0.655823, 0.092183, 0.134792, 0.002883};
static int __CompoundDataNISTList_Elements_93[] = {6, 8, 12};
static double __CompoundDataNISTList_massFractions_93[] = {0.142455, 0.569278, 0.288267};
static int __CompoundDataNISTList_Elements_94[] = {9, 12};
static double __CompoundDataNISTList_massFractions_94[] = {0.609883, 0.390117};
static int __CompoundDataNISTList_Elements_95[] = {8, 12};
static double __CompoundDataNISTList_massFractions_95[] = {0.396964, 0.603036};
static int __CompoundDataNISTList_Elements_96[] = {5, 8, 12};
static double __CompoundDataNISTList_massFractions_96[] = {0.240837, 0.623790, 0.135373};
static int __CompoundDataNISTList_Elements_97[] = {53, 80};
static double __CompoundDataNISTList_massFractions_97[] = {0.558560, 0.441440};
static int __CompoundDataNISTList_Elements_98[] = {1, 6};
static double __CompoundDataNISTList_massFractions_98[] = {0.251306, 0.748694};
static int __CompoundDataNISTList_Elements_99[] = {1, 6, 8};
static double __CompoundDataNISTList_massFractions_99[] = {0.125822, 0.374852, 0.499326};
static int __CompoundDataNISTList_Elements_100[] = {1, 6, 8, 12, 22};
static double __CompoundDataNISTList_massFractions_100[] = {0.134040, 0.777960, 0.035020, 0.038594, 0.014386};
static int __CompoundDataNISTList_Elements_101[] = {1, 6, 7, 8, 12, 17};
static double __CompoundDataNISTList_massFractions_101[] = {0.081192, 0.583442, 0.017798, 0.186381, 0.130287, 0.000900};
static int __CompoundDataNISTList_Elements_102[] = {1, 6, 7, 8, 11, 12, 15, 16, 17, 19, 20, 26, 30};
static double __CompoundDataNISTList_massFractions_102[] = {0.100637, 0.107830, 0.027680, 0.754773, 0.000750, 0.000190, 0.001800, 0.002410, 0.000790, 0.003020, 0.000030, 0.000040, 0.000050};
static int __CompoundDataNISTList_Elements_103[] = {1, 6, 7, 8, 11, 12, 15, 16, 19};
static double __CompoundDataNISTList_massFractions_103[] = {0.101997, 0.123000, 0.035000, 0.729003, 0.000800, 0.000200, 0.002000, 0.005000, 0.003000};
static int __CompoundDataNISTList_Elements_104[] = {1, 6, 7, 8};
static double __CompoundDataNISTList_massFractions_104[] = {0.098234, 0.156214, 0.035451, 0.710100};
static int __CompoundDataNISTList_Elements_105[] = {1, 6, 7, 8};
static double __CompoundDataNISTList_massFractions_105[] = {0.101969, 0.120058, 0.035451, 0.742522};
static int __CompoundDataNISTList_Elements_106[] = {1, 6};
static double __CompoundDataNISTList_massFractions_106[] = {0.062909, 0.937091};
static int __CompoundDataNISTList_Elements_107[] = {1, 6, 7, 8};
static double __CompoundDataNISTList_massFractions_107[] = {0.040935, 0.585374, 0.113773, 0.259918};
static int __CompoundDataNISTList_Elements_108[] = {7, 8};
static double __CompoundDataNISTList_massFractions_108[] = {0.636483, 0.363517};
static int __CompoundDataNISTList_Elements_109[] = {1, 6, 7, 8};
static double __CompoundDataNISTList_massFractions_109[] = {0.103509, 0.648415, 0.099536, 0.148539};
static int __CompoundDataNISTList_Elements_110[] = {1, 6, 7, 8};
static double __CompoundDataNISTList_massFractions_110[] = {0.097976, 0.636856, 0.123779, 0.141389};
static int __CompoundDataNISTList_Elements_111[] = {1, 6, 7, 8};
static double __CompoundDataNISTList_massFractions_111[] = {0.107062, 0.680449, 0.099189, 0.113300};
static int __CompoundDataNISTList_Elements_112[] = {1, 6, 7, 8};
static double __CompoundDataNISTList_massFractions_112[] = {0.115476, 0.720819, 0.076417, 0.087289};
static int __CompoundDataNISTList_Elements_113[] = {1, 6};
static double __CompoundDataNISTList_massFractions_113[] = {0.158821, 0.841179};
static int __CompoundDataNISTList_Elements_114[] = {1, 6};
static double __CompoundDataNISTList_massFractions_114[] = {0.148605, 0.851395};
static int __CompoundDataNISTList_Elements_115[] = {1, 6};
static double __CompoundDataNISTList_massFractions_115[] = {0.167635, 0.832365};
static int __CompoundDataNISTList_Elements_116[] = {1, 6, 7, 8, 16, 35, 47, 53};
static double __CompoundDataNISTList_massFractions_116[] = {0.014100, 0.072261, 0.019320, 0.066101, 0.001890, 0.349103, 0.474105, 0.003120};
static int __CompoundDataNISTList_Elements_117[] = {1, 6};
static double __CompoundDataNISTList_massFractions_117[] = {0.085000, 0.915000};
static int __CompoundDataNISTList_Elements_118[] = {8, 94};
static double __CompoundDataNISTList_massFractions_118[] = {0.118055, 0.881945};
static int __CompoundDataNISTList_Elements_119[] = {1, 6, 7};
static double __CompoundDataNISTList_massFractions_119[] = {0.056983, 0.679056, 0.263962};
static int __CompoundDataNISTList_Elements_120[] = {1, 6, 8};
static double __CompoundDataNISTList_massFractions_120[] = {0.055491, 0.755751, 0.188758};
static int __CompoundDataNISTList_Elements_121[] = {1, 6, 17};
static double __CompoundDataNISTList_massFractions_121[] = {0.061869, 0.696325, 0.241806};
static int __CompoundDataNISTList_Elements_122[] = {1, 6};
static double __CompoundDataNISTList_massFractions_122[] = {0.143711, 0.856289};
static int __CompoundDataNISTList_Elements_123[] = {1, 6, 8};
static double __CompoundDataNISTList_massFractions_123[] = {0.041959, 0.625017, 0.333025};
static int __CompoundDataNISTList_Elements_124[] = {1, 6, 8};
static double __CompoundDataNISTList_massFractions_124[] = {0.080538, 0.599848, 0.319614};
static int __CompoundDataNISTList_Elements_125[] = {1, 6, 8};
static double __CompoundDataNISTList_massFractions_125[] = {0.067135, 0.400017, 0.532848};
static int __CompoundDataNISTList_Elements_126[] = {1, 6};
static double __CompoundDataNISTList_massFractions_126[] = {0.143711, 0.856289};
static int __CompoundDataNISTList_Elements_127[] = {1, 6};
static double __CompoundDataNISTList_massFractions_127[] = {0.077418, 0.922582};
static int __CompoundDataNISTList_Elements_128[] = {6, 9};
static double __CompoundDataNISTList_massFractions_128[] = {0.240183, 0.759817};
static int __CompoundDataNISTList_Elements_129[] = {6, 9, 17};
static double __CompoundDataNISTList_massFractions_129[] = {0.206250, 0.489354, 0.304395};
static int __CompoundDataNISTList_Elements_130[] = {1, 6, 8};
static double __CompoundDataNISTList_massFractions_130[] = {0.070245, 0.558066, 0.371689};
static int __CompoundDataNISTList_Elements_131[] = {1, 6, 8};
static double __CompoundDataNISTList_massFractions_131[] = {0.091517, 0.545298, 0.363185};
static int __CompoundDataNISTList_Elements_132[] = {1, 6, 8};
static double __CompoundDataNISTList_massFractions_132[] = {0.092802, 0.680561, 0.226637};
static int __CompoundDataNISTList_Elements_133[] = {1, 6, 17};
static double __CompoundDataNISTList_massFractions_133[] = {0.048380, 0.384360, 0.567260};
static int __CompoundDataNISTList_Elements_134[] = {1, 6, 17};
static double __CompoundDataNISTList_massFractions_134[] = {0.020793, 0.247793, 0.731413};
static int __CompoundDataNISTList_Elements_135[] = {1, 6, 9};
static double __CompoundDataNISTList_massFractions_135[] = {0.031480, 0.375141, 0.593379};
static int __CompoundDataNISTList_Elements_136[] = {1, 6, 7, 8};
static double __CompoundDataNISTList_massFractions_136[] = {0.081616, 0.648407, 0.126024, 0.143953};
static int __CompoundDataNISTList_Elements_137[] = {19, 53};
static double __CompoundDataNISTList_massFractions_137[] = {0.235528, 0.764472};
static int __CompoundDataNISTList_Elements_138[] = {8, 19};
static double __CompoundDataNISTList_massFractions_138[] = {0.169852, 0.830148};
static int __CompoundDataNISTList_Elements_139[] = {1, 6};
static double __CompoundDataNISTList_massFractions_139[] = {0.182855, 0.817145};
static int __CompoundDataNISTList_Elements_140[] = {1, 6};
static double __CompoundDataNISTList_massFractions_140[] = {0.182855, 0.817145};
static int __CompoundDataNISTList_Elements_141[] = {1, 6, 8};
static double __CompoundDataNISTList_massFractions_141[] = {0.134173, 0.599595, 0.266232};
static int __CompoundDataNISTList_Elements_142[] = {1, 6, 7};
static double __CompoundDataNISTList_massFractions_142[] = {0.063710, 0.759217, 0.177073};
static int __CompoundDataNISTList_Elements_143[] = {1, 6};
static double __CompoundDataNISTList_massFractions_143[] = {0.143711, 0.856289};
static int __CompoundDataNISTList_Elements_144[] = {1, 6};
static double __CompoundDataNISTList_massFractions_144[] = {0.118371, 0.881629};
static int __CompoundDataNISTList_Elements_145[] = {1, 6, 17};
static double __CompoundDataNISTList_massFractions_145[] = {0.056920, 0.542646, 0.400434};
static int __CompoundDataNISTList_Elements_146[] = {8, 14};
static double __CompoundDataNISTList_massFractions_146[] = {0.532565, 0.467435};
static int __CompoundDataNISTList_Elements_147[] = {35, 47};
static double __CompoundDataNISTList_massFractions_147[] = {0.425537, 0.574463};
static int __CompoundDataNISTList_Elements_148[] = {17, 47};
static double __CompoundDataNISTList_massFractions_148[] = {0.247368, 0.752632};
static int __CompoundDataNISTList_Elements_149[] = {35, 47, 53};
static double __CompoundDataNISTList_massFractions_149[] = {0.422895, 0.573748, 0.003357};
static int __CompoundDataNISTList_Elements_150[] = {47, 53};
static double __CompoundDataNISTList_massFractions_150[] = {0.459458, 0.540542};
static int __CompoundDataNISTList_Elements_151[] = {1, 6, 7, 8, 11, 12, 15, 16, 17, 19, 20, 26, 30};
static double __CompoundDataNISTList_massFractions_151[] = {0.100588, 0.228250, 0.046420, 0.619002, 0.000070, 0.000060, 0.000330, 0.001590, 0.002670, 0.000850, 0.000150, 0.000010, 0.000010};
static int __CompoundDataNISTList_Elements_152[] = {6, 8, 11};
static double __CompoundDataNISTList_massFractions_152[] = {0.113323, 0.452861, 0.433815};
static int __CompoundDataNISTList_Elements_153[] = {11, 53};
static double __CompoundDataNISTList_massFractions_153[] = {0.153373, 0.846627};
static int __CompoundDataNISTList_Elements_154[] = {8, 11};
static double __CompoundDataNISTList_massFractions_154[] = {0.258143, 0.741857};
static int __CompoundDataNISTList_Elements_155[] = {7, 8, 11};
static double __CompoundDataNISTList_massFractions_155[] = {0.164795, 0.564720, 0.270485};
static int __CompoundDataNISTList_Elements_156[] = {1, 6};
static double __CompoundDataNISTList_massFractions_156[] = {0.067101, 0.932899};
static int __CompoundDataNISTList_Elements_157[] = {1, 6, 8};
static double __CompoundDataNISTList_massFractions_157[] = {0.064779, 0.421070, 0.514151};
static int __CompoundDataNISTList_Elements_158[] = {1, 6};
static double __CompoundDataNISTList_massFractions_158[] = {0.044543, 0.955457};
static int __CompoundDataNISTList_Elements_159[] = {1, 6, 7, 8, 11, 12, 15, 16, 17, 19, 20, 26, 30};
static double __CompoundDataNISTList_massFractions_159[] = {0.104166, 0.092270, 0.019940, 0.773884, 0.002260, 0.000110, 0.001250, 0.001460, 0.002440, 0.002080, 0.000100, 0.000020, 0.000020};
static int __CompoundDataNISTList_Elements_160[] = {6, 17};
static double __CompoundDataNISTList_massFractions_160[] = {0.144856, 0.855144};
static int __CompoundDataNISTList_Elements_161[] = {17, 81};
static double __CompoundDataNISTList_massFractions_161[] = {0.147822, 0.852178};
static int __CompoundDataNISTList_Elements_162[] = {1, 6, 7, 8, 11, 12, 15, 16, 17, 19, 20, 26, 30};
static double __CompoundDataNISTList_massFractions_162[] = {0.104472, 0.232190, 0.024880, 0.630238, 0.001130, 0.000130, 0.001330, 0.001990, 0.001340, 0.001990, 0.000230, 0.000050, 0.000030};
static int __CompoundDataNISTList_Elements_163[] = {1, 6, 7, 8};
static double __CompoundDataNISTList_massFractions_163[] = {0.101172, 0.111000, 0.026000, 0.761828};
static int __CompoundDataNISTList_Elements_164[] = {1, 6, 7, 8};
static double __CompoundDataNISTList_massFractions_164[] = {0.101869, 0.456179, 0.035172, 0.406780};
static int __CompoundDataNISTList_Elements_165[] = {1, 6, 7, 8};
static double __CompoundDataNISTList_massFractions_165[] = {0.102672, 0.568940, 0.035022, 0.293366};
static int __CompoundDataNISTList_Elements_166[] = {8, 22};
static double __CompoundDataNISTList_massFractions_166[] = {0.400592, 0.599408};
static int __CompoundDataNISTList_Elements_167[] = {1, 6};
static double __CompoundDataNISTList_massFractions_167[] = {0.087510, 0.912490};
static int __CompoundDataNISTList_Elements_168[] = {1, 6, 17};
static double __CompoundDataNISTList_massFractions_168[] = {0.007671, 0.182831, 0.809498};
static int __CompoundDataNISTList_Elements_169[] = {1, 6, 8, 15};
static double __CompoundDataNISTList_massFractions_169[] = {0.082998, 0.395628, 0.351334, 0.170040};
static int __CompoundDataNISTList_Elements_170[] = {9, 74};
static double __CompoundDataNISTList_massFractions_170[] = {0.382723, 0.617277};
static int __CompoundDataNISTList_Elements_171[] = {6, 92};
static double __CompoundDataNISTList_massFractions_171[] = {0.091669, 0.908331};
static int __CompoundDataNISTList_Elements_172[] = {6, 92};
static double __CompoundDataNISTList_massFractions_172[] = {0.048036, 0.951964};
static int __CompoundDataNISTList_Elements_173[] = {8, 92};
static double __CompoundDataNISTList_massFractions_173[] = {0.118502, 0.881498};
static int __CompoundDataNISTList_Elements_174[] = {1, 6, 7, 8};
static double __CompoundDataNISTList_massFractions_174[] = {0.067131, 0.199999, 0.466459, 0.266411};
static int __CompoundDataNISTList_Elements_175[] = {1, 6, 7, 8};
static double __CompoundDataNISTList_massFractions_175[] = {0.094641, 0.512645, 0.119565, 0.273150};
static int __CompoundDataNISTList_Elements_176[] = {1, 6, 9};
static double __CompoundDataNISTList_massFractions_176[] = {0.009417, 0.280555, 0.710028};
static int __CompoundDataNISTList_Elements_177[] = {1, 8};
static double __CompoundDataNISTList_massFractions_177[] = {0.111894, 0.888106};
static int __CompoundDataNISTList_Elements_178[] = {1, 8};
static double __CompoundDataNISTList_massFractions_178[] = {0.111894, 0.888106};
static int __CompoundDataNISTList_Elements_179[] = {1, 6};
static double __CompoundDataNISTList_massFractions_179[] = {0.094935, 0.905065};
static const struct compoundDataNIST compoundDataNISTList[] = {
{"A-150 Tissue-Equivalent Plastic" ,6, __CompoundDataNISTList_Elements_0, __CompoundDataNISTList_massFractions_0, 1.127000},
{"Acetone" ,3, __CompoundDataNISTList_Elements_1, __CompoundDataNISTList_massFractions_1, 0.789900},
{"Acetylene" ,2, __CompoundDataNISTList_Elements_2, __CompoundDataNISTList_massFractions_2, 0.001097},
{"Adenine" ,3, __CompoundDataNISTList_Elements_3, __CompoundDataNISTList_massFractions_3, 1.350000},
{"Adipose Tissue (ICRP)" ,13, __CompoundDataNISTList_Elements_4, __CompoundDataNISTList_massFractions_4, 0.920000},
{"Air, Dry (near sea level)" ,4, __CompoundDataNISTList_Elements_5, __CompoundDataNISTList_massFractions_5, 0.001205},
{"Alanine" ,4, __CompoundDataNISTList_Elements_6, __CompoundDataNISTList_massFractions_6, 1.420000},
{"Aluminum Oxide" ,2, __CompoundDataNISTList_Elements_7, __CompoundDataNISTList_massFractions_7, 3.970000},
{"Amber" ,3, __CompoundDataNISTList_Elements_8, __CompoundDataNISTList_massFractions_8, 1.100000},
{"Ammonia" ,2, __CompoundDataNISTList_Elements_9, __CompoundDataNISTList_massFractions_9, 0.000826},
{"Aniline" ,3, __CompoundDataNISTList_Elements_10, __CompoundDataNISTList_massFractions_10, 1.023500},
{"Anthracene" ,2, __CompoundDataNISTList_Elements_11, __CompoundDataNISTList_massFractions_11, 1.283000},
{"B-100 Bone-Equivalent Plastic" ,6, __CompoundDataNISTList_Elements_12, __CompoundDataNISTList_massFractions_12, 1.450000},
{"Bakelite" ,3, __CompoundDataNISTList_Elements_13, __CompoundDataNISTList_massFractions_13, 1.250000},
{"Barium Fluoride" ,2, __CompoundDataNISTList_Elements_14, __CompoundDataNISTList_massFractions_14, 4.890000},
{"Barium Sulfate" ,3, __CompoundDataNISTList_Elements_15, __CompoundDataNISTList_massFractions_15, 4.500000},
{"Benzene" ,2, __CompoundDataNISTList_Elements_16, __CompoundDataNISTList_massFractions_16, 0.878650},
{"Beryllium oxide" ,2, __CompoundDataNISTList_Elements_17, __CompoundDataNISTList_massFractions_17, 3.010000},
{"Bismuth Germanium oxide" ,3, __CompoundDataNISTList_Elements_18, __CompoundDataNISTList_massFractions_18, 7.130000},
{"Blood (ICRP)" ,14, __CompoundDataNISTList_Elements_19, __CompoundDataNISTList_massFractions_19, 1.060000},
{"Bone, Compact (ICRU)" ,8, __CompoundDataNISTList_Elements_20, __CompoundDataNISTList_massFractions_20, 1.850000},
{"Bone, Cortical (ICRP)" ,9, __CompoundDataNISTList_Elements_21, __CompoundDataNISTList_massFractions_21, 1.850000},
{"Boron Carbide" ,2, __CompoundDataNISTList_Elements_22, __CompoundDataNISTList_massFractions_22, 2.520000},
{"Boron Oxide" ,2, __CompoundDataNISTList_Elements_23, __CompoundDataNISTList_massFractions_23, 1.812000},
{"Brain (ICRP)" ,13, __CompoundDataNISTList_Elements_24, __CompoundDataNISTList_massFractions_24, 1.030000},
{"Butane" ,2, __CompoundDataNISTList_Elements_25, __CompoundDataNISTList_massFractions_25, 0.002493},
{"N-Butyl Alcohol" ,3, __CompoundDataNISTList_Elements_26, __CompoundDataNISTList_massFractions_26, 0.809800},
{"C-552 Air-Equivalent Plastic" ,5, __CompoundDataNISTList_Elements_27, __CompoundDataNISTList_massFractions_27, 1.760000},
{"Cadmium Telluride" ,2, __CompoundDataNISTList_Elements_28, __CompoundDataNISTList_massFractions_28, 6.200000},
{"Cadmium Tungstate" ,3, __CompoundDataNISTList_Elements_29, __CompoundDataNISTList_massFractions_29, 7.900000},
{"Calcium Carbonate" ,3, __CompoundDataNISTList_Elements_30, __CompoundDataNISTList_massFractions_30, 2.800000},
{"Calcium Fluoride" ,2, __CompoundDataNISTList_Elements_31, __CompoundDataNISTList_massFractions_31, 3.180000},
{"Calcium Oxide" ,2, __CompoundDataNISTList_Elements_32, __CompoundDataNISTList_massFractions_32, 3.300000},
{"Calcium Sulfate" ,3, __CompoundDataNISTList_Elements_33, __CompoundDataNISTList_massFractions_33, 2.960000},
{"Calcium Tungstate" ,3, __CompoundDataNISTList_Elements_34, __CompoundDataNISTList_massFractions_34, 6.062000},
{"Carbon Dioxide" ,2, __CompoundDataNISTList_Elements_35, __CompoundDataNISTList_massFractions_35, 0.001842},
{"Carbon Tetrachloride" ,2, __CompoundDataNISTList_Elements_36, __CompoundDataNISTList_massFractions_36, 1.594000},
{"Cellulose Acetate, Cellophane" ,3, __CompoundDataNISTList_Elements_37, __CompoundDataNISTList_massFractions_37, 1.420000},
{"Cellulose Acetate Butyrate" ,3, __CompoundDataNISTList_Elements_38, __CompoundDataNISTList_massFractions_38, 1.200000},
{"Cellulose Nitrate" ,4, __CompoundDataNISTList_Elements_39, __CompoundDataNISTList_massFractions_39, 1.490000},
{"Ceric Sulfate Dosimeter Solution" ,5, __CompoundDataNISTList_Elements_40, __CompoundDataNISTList_massFractions_40, 1.030000},
{"Cesium Fluoride" ,2, __CompoundDataNISTList_Elements_41, __CompoundDataNISTList_massFractions_41, 4.115000},
{"Cesium Iodide" ,2, __CompoundDataNISTList_Elements_42, __CompoundDataNISTList_massFractions_42, 4.510000},
{"Chlorobenzene" ,3, __CompoundDataNISTList_Elements_43, __CompoundDataNISTList_massFractions_43, 1.105800},
{"Chloroform" ,3, __CompoundDataNISTList_Elements_44, __CompoundDataNISTList_massFractions_44, 1.483200},
{"Concrete, Portland" ,10, __CompoundDataNISTList_Elements_45, __CompoundDataNISTList_massFractions_45, 2.300000},
{"Cyclohexane" ,2, __CompoundDataNISTList_Elements_46, __CompoundDataNISTList_massFractions_46, 0.779000},
{"1,2-Ddihlorobenzene" ,3, __CompoundDataNISTList_Elements_47, __CompoundDataNISTList_massFractions_47, 1.304800},
{"Dichlorodiethyl Ether" ,4, __CompoundDataNISTList_Elements_48, __CompoundDataNISTList_massFractions_48, 1.219900},
{"1,2-Dichloroethane" ,3, __CompoundDataNISTList_Elements_49, __CompoundDataNISTList_massFractions_49, 1.235100},
{"Diethyl Ether" ,3, __CompoundDataNISTList_Elements_50, __CompoundDataNISTList_massFractions_50, 0.713780},
{"N,N-Dimethyl Formamide" ,4, __CompoundDataNISTList_Elements_51, __CompoundDataNISTList_massFractions_51, 0.948700},
{"Dimethyl Sulfoxide" ,4, __CompoundDataNISTList_Elements_52, __CompoundDataNISTList_massFractions_52, 1.101400},
{"Ethane" ,2, __CompoundDataNISTList_Elements_53, __CompoundDataNISTList_massFractions_53, 0.001253},
{"Ethyl Alcohol" ,3, __CompoundDataNISTList_Elements_54, __CompoundDataNISTList_massFractions_54, 0.789300},
{"Ethyl Cellulose" ,3, __CompoundDataNISTList_Elements_55, __CompoundDataNISTList_massFractions_55, 1.130000},
{"Ethylene" ,2, __CompoundDataNISTList_Elements_56, __CompoundDataNISTList_massFractions_56, 0.001175},
{"Eye Lens (ICRP)" ,4, __CompoundDataNISTList_Elements_57, __CompoundDataNISTList_massFractions_57, 1.100000},
{"Ferric Oxide" ,2, __CompoundDataNISTList_Elements_58, __CompoundDataNISTList_massFractions_58, 5.200000},
{"Ferroboride" ,2, __CompoundDataNISTList_Elements_59, __CompoundDataNISTList_massFractions_59, 7.150000},
{"Ferrous Oxide" ,2, __CompoundDataNISTList_Elements_60, __CompoundDataNISTList_massFractions_60, 5.700000},
{"Ferrous Sulfate Dosimeter Solution" ,7, __CompoundDataNISTList_Elements_61, __CompoundDataNISTList_massFractions_61, 1.024000},
{"Freon-12" ,3, __CompoundDataNISTList_Elements_62, __CompoundDataNISTList_massFractions_62, 1.120000},
{"Freon-12B2" ,3, __CompoundDataNISTList_Elements_63, __CompoundDataNISTList_massFractions_63, 1.800000},
{"Freon-13" ,3, __CompoundDataNISTList_Elements_64, __CompoundDataNISTList_massFractions_64, 0.950000},
{"Freon-13B1" ,3, __CompoundDataNISTList_Elements_65, __CompoundDataNISTList_massFractions_65, 1.500000},
{"Freon-13I1" ,3, __CompoundDataNISTList_Elements_66, __CompoundDataNISTList_massFractions_66, 1.800000},
{"Gadolinium Oxysulfide" ,3, __CompoundDataNISTList_Elements_67, __CompoundDataNISTList_massFractions_67, 7.440000},
{"Gallium Arsenide" ,2, __CompoundDataNISTList_Elements_68, __CompoundDataNISTList_massFractions_68, 5.310000},
{"Gel in Photographic Emulsion" ,5, __CompoundDataNISTList_Elements_69, __CompoundDataNISTList_massFractions_69, 1.291400},
{"Glass, Pyrex" ,6, __CompoundDataNISTList_Elements_70, __CompoundDataNISTList_massFractions_70, 2.230000},
{"Glass, Lead" ,5, __CompoundDataNISTList_Elements_71, __CompoundDataNISTList_massFractions_71, 6.220000},
{"Glass, Plate" ,4, __CompoundDataNISTList_Elements_72, __CompoundDataNISTList_massFractions_72, 2.400000},
{"Glucose" ,3, __CompoundDataNISTList_Elements_73, __CompoundDataNISTList_massFractions_73, 1.540000},
{"Glutamine" ,4, __CompoundDataNISTList_Elements_74, __CompoundDataNISTList_massFractions_74, 1.460000},
{"Glycerol" ,3, __CompoundDataNISTList_Elements_75, __CompoundDataNISTList_massFractions_75, 1.261300},
{"Guanine" ,4, __CompoundDataNISTList_Elements_76, __CompoundDataNISTList_massFractions_76, 1.580000},
{"Gypsum, Plaster of Paris" ,4, __CompoundDataNISTList_Elements_77, __CompoundDataNISTList_massFractions_77, 2.320000},
{"N-Heptane" ,2, __CompoundDataNISTList_Elements_78, __CompoundDataNISTList_massFractions_78, 0.683760},
{"N-Hexane" ,2, __CompoundDataNISTList_Elements_79, __CompoundDataNISTList_massFractions_79, 0.660300},
{"Kapton Polyimide Film" ,4, __CompoundDataNISTList_Elements_80, __CompoundDataNISTList_massFractions_80, 1.420000},
{"Lanthanum Oxybromide" ,3, __CompoundDataNISTList_Elements_81, __CompoundDataNISTList_massFractions_81, 6.280000},
{"Lanthanum Oxysulfide" ,3, __CompoundDataNISTList_Elements_82, __CompoundDataNISTList_massFractions_82, 5.860000},
{"Lead Oxide" ,2, __CompoundDataNISTList_Elements_83, __CompoundDataNISTList_massFractions_83, 9.530000},
{"Lithium Amide" ,3, __CompoundDataNISTList_Elements_84, __CompoundDataNISTList_massFractions_84, 1.178000},
{"Lithium Carbonate" ,3, __CompoundDataNISTList_Elements_85, __CompoundDataNISTList_massFractions_85, 2.110000},
{"Lithium Fluoride" ,2, __CompoundDataNISTList_Elements_86, __CompoundDataNISTList_massFractions_86, 2.635000},
{"Lithium Hydride" ,2, __CompoundDataNISTList_Elements_87, __CompoundDataNISTList_massFractions_87, 0.820000},
{"Lithium Iodide" ,2, __CompoundDataNISTList_Elements_88, __CompoundDataNISTList_massFractions_88, 3.494000},
{"Lithium Oxide" ,2, __CompoundDataNISTList_Elements_89, __CompoundDataNISTList_massFractions_89, 2.013000},
{"Lithium Tetraborate" ,3, __CompoundDataNISTList_Elements_90, __CompoundDataNISTList_massFractions_90, 2.440000},
{"Lung (ICRP)" ,13, __CompoundDataNISTList_Elements_91, __CompoundDataNISTList_massFractions_91, 1.050000},
{"M3 Wax" ,5, __CompoundDataNISTList_Elements_92, __CompoundDataNISTList_massFractions_92, 1.050000},
{"Magnesium Carbonate" ,3, __CompoundDataNISTList_Elements_93, __CompoundDataNISTList_massFractions_93, 2.958000},
{"Magnesium Fluoride" ,2, __CompoundDataNISTList_Elements_94, __CompoundDataNISTList_massFractions_94, 3.000000},
{"Magnesium Oxide" ,2, __CompoundDataNISTList_Elements_95, __CompoundDataNISTList_massFractions_95, 3.580000},
{"Magnesium Tetraborate" ,3, __CompoundDataNISTList_Elements_96, __CompoundDataNISTList_massFractions_96, 2.530000},
{"Mercuric Iodide" ,2, __CompoundDataNISTList_Elements_97, __CompoundDataNISTList_massFractions_97, 6.360000},
{"Methane" ,2, __CompoundDataNISTList_Elements_98, __CompoundDataNISTList_massFractions_98, 0.000667},
{"Methanol" ,3, __CompoundDataNISTList_Elements_99, __CompoundDataNISTList_massFractions_99, 0.791400},
{"Mix D Wax" ,5, __CompoundDataNISTList_Elements_100, __CompoundDataNISTList_massFractions_100, 0.990000},
{"MS20 Tissue Substitute" ,6, __CompoundDataNISTList_Elements_101, __CompoundDataNISTList_massFractions_101, 1.000000},
{"Muscle, Skeletal" ,13, __CompoundDataNISTList_Elements_102, __CompoundDataNISTList_massFractions_102, 1.040000},
{"Muscle, Striated" ,9, __CompoundDataNISTList_Elements_103, __CompoundDataNISTList_massFractions_103, 1.040000},
{"Muscle-Equivalent Liquid, with Sucrose" ,4, __CompoundDataNISTList_Elements_104, __CompoundDataNISTList_massFractions_104, 1.110000},
{"Muscle-Equivalent Liquid, without Sucrose" ,4, __CompoundDataNISTList_Elements_105, __CompoundDataNISTList_massFractions_105, 1.070000},
{"Naphthalene" ,2, __CompoundDataNISTList_Elements_106, __CompoundDataNISTList_massFractions_106, 1.145000},
{"Nitrobenzene" ,4, __CompoundDataNISTList_Elements_107, __CompoundDataNISTList_massFractions_107, 1.198670},
{"Nitrous Oxide" ,2, __CompoundDataNISTList_Elements_108, __CompoundDataNISTList_massFractions_108, 0.001831},
{"Nylon, Du Pont ELVAmide 8062" ,4, __CompoundDataNISTList_Elements_109, __CompoundDataNISTList_massFractions_109, 1.080000},
{"Nylon, type 6 and type 6/6" ,4, __CompoundDataNISTList_Elements_110, __CompoundDataNISTList_massFractions_110, 1.140000},
{"Nylon, type 6/10" ,4, __CompoundDataNISTList_Elements_111, __CompoundDataNISTList_massFractions_111, 1.140000},
{"Nylon, type 11 (Rilsan)" ,4, __CompoundDataNISTList_Elements_112, __CompoundDataNISTList_massFractions_112, 1.425000},
{"Octane, Liquid" ,2, __CompoundDataNISTList_Elements_113, __CompoundDataNISTList_massFractions_113, 0.702600},
{"Paraffin Wax" ,2, __CompoundDataNISTList_Elements_114, __CompoundDataNISTList_massFractions_114, 0.930000},
{"N-Pentane" ,2, __CompoundDataNISTList_Elements_115, __CompoundDataNISTList_massFractions_115, 0.626200},
{"Photographic Emulsion" ,8, __CompoundDataNISTList_Elements_116, __CompoundDataNISTList_massFractions_116, 3.815000},
{"Plastic Scintillator (Vinyltoluene based)" ,2, __CompoundDataNISTList_Elements_117, __CompoundDataNISTList_massFractions_117, 1.032000},
{"Plutonium Dioxide" ,2, __CompoundDataNISTList_Elements_118, __CompoundDataNISTList_massFractions_118, 11.460000},
{"Polyacrylonitrile" ,3, __CompoundDataNISTList_Elements_119, __CompoundDataNISTList_massFractions_119, 1.170000},
{"Polycarbonate (Makrolon, Lexan)" ,3, __CompoundDataNISTList_Elements_120, __CompoundDataNISTList_massFractions_120, 1.200000},
{"Polychlorostyrene" ,3, __CompoundDataNISTList_Elements_121, __CompoundDataNISTList_massFractions_121, 1.300000},
{"Polyethylene" ,2, __CompoundDataNISTList_Elements_122, __CompoundDataNISTList_massFractions_122, 0.940000},
{"Polyethylene Terephthalate (Mylar)" ,3, __CompoundDataNISTList_Elements_123, __CompoundDataNISTList_massFractions_123, 1.400000},
{"Polymethyl Methacralate (Lucite, Perspex)" ,3, __CompoundDataNISTList_Elements_124, __CompoundDataNISTList_massFractions_124, 1.190000},
{"Polyoxymethylene" ,3, __CompoundDataNISTList_Elements_125, __CompoundDataNISTList_massFractions_125, 1.425000},
{"Polypropylene" ,2, __CompoundDataNISTList_Elements_126, __CompoundDataNISTList_massFractions_126, 0.900000},
{"Polystyrene" ,2, __CompoundDataNISTList_Elements_127, __CompoundDataNISTList_massFractions_127, 1.060000},
{"Polytetrafluoroethylene (Teflon)" ,2, __CompoundDataNISTList_Elements_128, __CompoundDataNISTList_massFractions_128, 2.200000},
{"Polytrifluorochloroethylene" ,3, __CompoundDataNISTList_Elements_129, __CompoundDataNISTList_massFractions_129, 2.100000},
{"Polyvinyl Acetate" ,3, __CompoundDataNISTList_Elements_130, __CompoundDataNISTList_massFractions_130, 1.190000},
{"Polyvinyl Alcohol" ,3, __CompoundDataNISTList_Elements_131, __CompoundDataNISTList_massFractions_131, 1.300000},
{"Polyvinyl Butyral" ,3, __CompoundDataNISTList_Elements_132, __CompoundDataNISTList_massFractions_132, 1.120000},
{"Polyvinyl Chloride" ,3, __CompoundDataNISTList_Elements_133, __CompoundDataNISTList_massFractions_133, 1.300000},
{"Polyvinylidene Chloride, Saran" ,3, __CompoundDataNISTList_Elements_134, __CompoundDataNISTList_massFractions_134, 1.700000},
{"Polyvinylidene Fluoride" ,3, __CompoundDataNISTList_Elements_135, __CompoundDataNISTList_massFractions_135, 1.760000},
{"Polyvinyl Pyrrolidone" ,4, __CompoundDataNISTList_Elements_136, __CompoundDataNISTList_massFractions_136, 1.250000},
{"Potassium Iodide" ,2, __CompoundDataNISTList_Elements_137, __CompoundDataNISTList_massFractions_137, 3.130000},
{"Potassium Oxide" ,2, __CompoundDataNISTList_Elements_138, __CompoundDataNISTList_massFractions_138, 2.320000},
{"Propane" ,2, __CompoundDataNISTList_Elements_139, __CompoundDataNISTList_massFractions_139, 0.001879},
{"Propane, Liquid" ,2, __CompoundDataNISTList_Elements_140, __CompoundDataNISTList_massFractions_140, 0.430000},
{"N-Propyl Alcohol" ,3, __CompoundDataNISTList_Elements_141, __CompoundDataNISTList_massFractions_141, 0.803500},
{"Pyridine" ,3, __CompoundDataNISTList_Elements_142, __CompoundDataNISTList_massFractions_142, 0.981900},
{"Rubber, Butyl" ,2, __CompoundDataNISTList_Elements_143, __CompoundDataNISTList_massFractions_143, 0.920000},
{"Rubber, Natural" ,2, __CompoundDataNISTList_Elements_144, __CompoundDataNISTList_massFractions_144, 0.920000},
{"Rubber, Neoprene" ,3, __CompoundDataNISTList_Elements_145, __CompoundDataNISTList_massFractions_145, 1.230000},
{"Silicon Dioxide" ,2, __CompoundDataNISTList_Elements_146, __CompoundDataNISTList_massFractions_146, 2.320000},
{"Silver Bromide" ,2, __CompoundDataNISTList_Elements_147, __CompoundDataNISTList_massFractions_147, 6.473000},
{"Silver Chloride" ,2, __CompoundDataNISTList_Elements_148, __CompoundDataNISTList_massFractions_148, 5.560000},
{"Silver Halides in Photographic Emulsion" ,3, __CompoundDataNISTList_Elements_149, __CompoundDataNISTList_massFractions_149, 6.470000},
{"Silver Iodide" ,2, __CompoundDataNISTList_Elements_150, __CompoundDataNISTList_massFractions_150, 6.010000},
{"Skin (ICRP)" ,13, __CompoundDataNISTList_Elements_151, __CompoundDataNISTList_massFractions_151, 1.100000},
{"Sodium Carbonate" ,3, __CompoundDataNISTList_Elements_152, __CompoundDataNISTList_massFractions_152, 2.532000},
{"Sodium Iodide" ,2, __CompoundDataNISTList_Elements_153, __CompoundDataNISTList_massFractions_153, 3.667000},
{"Sodium Monoxide" ,2, __CompoundDataNISTList_Elements_154, __CompoundDataNISTList_massFractions_154, 2.270000},
{"Sodium Nitrate" ,3, __CompoundDataNISTList_Elements_155, __CompoundDataNISTList_massFractions_155, 2.261000},
{"Stilbene" ,2, __CompoundDataNISTList_Elements_156, __CompoundDataNISTList_massFractions_156, 0.970700},
{"Sucrose" ,3, __CompoundDataNISTList_Elements_157, __CompoundDataNISTList_massFractions_157, 1.580500},
{"Terphenyl" ,2, __CompoundDataNISTList_Elements_158, __CompoundDataNISTList_massFractions_158, 1.234000},
{"Testes (ICRP)" ,13, __CompoundDataNISTList_Elements_159, __CompoundDataNISTList_massFractions_159, 1.040000},
{"Tetrachloroethylene" ,2, __CompoundDataNISTList_Elements_160, __CompoundDataNISTList_massFractions_160, 1.625000},
{"Thallium Chloride" ,2, __CompoundDataNISTList_Elements_161, __CompoundDataNISTList_massFractions_161, 7.004000},
{"Tissue, Soft (ICRP)" ,13, __CompoundDataNISTList_Elements_162, __CompoundDataNISTList_massFractions_162, 1.000000},
{"Tissue, Soft (ICRU four-component)" ,4, __CompoundDataNISTList_Elements_163, __CompoundDataNISTList_massFractions_163, 1.000000},
{"Tissue-Equivalent GAS (Methane based)" ,4, __CompoundDataNISTList_Elements_164, __CompoundDataNISTList_massFractions_164, 0.001064},
{"Tissue-Equivalent GAS (Propane based)" ,4, __CompoundDataNISTList_Elements_165, __CompoundDataNISTList_massFractions_165, 0.001826},
{"Titanium Dioxide" ,2, __CompoundDataNISTList_Elements_166, __CompoundDataNISTList_massFractions_166, 4.260000},
{"Toluene" ,2, __CompoundDataNISTList_Elements_167, __CompoundDataNISTList_massFractions_167, 0.866900},
{"Trichloroethylene" ,3, __CompoundDataNISTList_Elements_168, __CompoundDataNISTList_massFractions_168, 1.460000},
{"Triethyl Phosphate" ,4, __CompoundDataNISTList_Elements_169, __CompoundDataNISTList_massFractions_169, 1.070000},
{"Tungsten Hexafluoride" ,2, __CompoundDataNISTList_Elements_170, __CompoundDataNISTList_massFractions_170, 2.400000},
{"Uranium Dicarbide" ,2, __CompoundDataNISTList_Elements_171, __CompoundDataNISTList_massFractions_171, 11.280000},
{"Uranium Monocarbide" ,2, __CompoundDataNISTList_Elements_172, __CompoundDataNISTList_massFractions_172, 13.630000},
{"Uranium Oxide" ,2, __CompoundDataNISTList_Elements_173, __CompoundDataNISTList_massFractions_173, 10.960000},
{"Urea" ,4, __CompoundDataNISTList_Elements_174, __CompoundDataNISTList_massFractions_174, 1.323000},
{"Valine" ,4, __CompoundDataNISTList_Elements_175, __CompoundDataNISTList_massFractions_175, 1.230000},
{"Viton Fluoroelastomer" ,3, __CompoundDataNISTList_Elements_176, __CompoundDataNISTList_massFractions_176, 1.800000},
{"Water, Liquid" ,2, __CompoundDataNISTList_Elements_177, __CompoundDataNISTList_massFractions_177, 1.000000},
{"Water Vapor" ,2, __CompoundDataNISTList_Elements_178, __CompoundDataNISTList_massFractions_178, 0.000756},
{"Xylene" ,2, __CompoundDataNISTList_Elements_179, __CompoundDataNISTList_massFractions_179, 0.870000}
};
